# -*- coding: utf-8 -*-
"""
(c)2013 ЗАО "РИПАС"
www.ripas.ru
"""

from RoadCentre import kernel, plugins, project
from spectr import tooltip

def controllerProperties():
	obj=kernel.selection()[0]
	if not obj.inherits("Spectr::Light"):
		return
	plugins.EditorPlugin.editObject(obj)

def removeControllers():
	objects=kernel.selection()
	from PythonQt import QtGui
	from gui import mainWindow
	if QtGui.QMessageBox.question(mainWindow,u'Вопрос',u'Удалить выбранные контроллеры?',QtGui.QMessageBox.Yes|QtGui.QMessageBox.No)!=QtGui.QMessageBox.Yes:
		return
	kernel.selectionModel.clearSelection()
	for obj in objects:
		if not obj.inherits("Spectr::Light"):
			continue
		obj.deleteLater()
		if not project.changed:
			project.changed=True

def setObjectsMoveMode(checked):
	for obj in project.objects():
		obj.movable=checked
	if hasattr(plugins,'CamLayerPlugin'):
		for cam in plugins.CamLayerPlugin.children():
			if cam.inherits('CamGraphicsItem'):
				cam.movable=checked

def addObject():
	kernel.selectionModel.clearSelection()
	plugins.EditorPlugin.connect('objectAdded(QPointF)',objectAdded)
	from PythonQt import QtGui
	plugins.EditorPlugin.startAddMode(kernel.graphicsScene,QtGui.QCursor(QtGui.QPixmap(":resources/add_object_cursor.png"),0,0))
	del QtGui

def addCamera():
	if not hasattr(plugins,'CamLayerPlugin'):
		return
	kernel.selectionModel.clearSelection()
	plugins.EditorPlugin.connect('objectAdded(QPointF)',cameraAdded)
	from PythonQt import QtGui
	plugins.EditorPlugin.startAddMode(kernel.graphicsScene,QtGui.QCursor(QtGui.QPixmap(":resources/add_camera_cursor.png"),0,0))
	del QtGui

def objectEdited(obj):
	tooltip.update(obj)
	project.changed=True
	project.updateObject(obj)
	obj.refresh(project.connection)
	if hasattr(obj,"temporary") and obj.temporary==True:
		kernel.itemModel.removeObject(u'Новые контроллеры',obj)
		kernel.itemModel.addObjects(u'Контроллеры',(obj,))
		obj.temporary=False
	else:
		kernel.itemModel.refreshObject(u'Контроллеры',obj)
	kernel.selectionModel.clear()
	obj.selected=True

def cameraAdded(pt):
	if not hasattr(plugins,'CamLayerPlugin'):
		return
	plugins.EditorPlugin.disconnect('objectAdded(QPointF)',cameraAdded)
	cam=plugins.CamLayerPlugin.createNewCamera(pt)
	if not cam:
		return
	type_visible=plugins.CamLayerPlugin.typeIsVisible(1)
	if not type_visible:
		plugins.CamLayerPlugin.setTypeVisible(1,True)
	cam.selected=True
	if not plugins.CamLayerPlugin.editCamProperties(cam):
		plugins.CamLayerPlugin.deleteCamera(cam)
		plugins.CamLayerPlugin.setTypeVisible(1,type_visible)
		return
	kernel.itemModel.addObjects(u'Камеры',(cam,))
	from cams import saveCamList
	saveCamList()
	del saveCamList
	plugins.CamLayerPlugin.setTypeVisible(1,type_visible)

def objectAdded(pt):
	kernel.selectionModel.clearSelection()
	plugins.EditorPlugin.disconnect('objectAdded(QPointF)',objectAdded)
	obj=project.createObject()
	if not obj:
		return
	obj.position=pt
	if not plugins.EditorPlugin.editObject(obj,False):
		obj.deleteLater()
		return
	project.addObject(obj)
	kernel.itemModel.addObjects(u'Контроллеры',(obj,))
	tooltip.update(obj)
	project.changed=True
	project.updateObject(obj)
	obj.refresh(project.connection)

def createProject():
	from actions import closeProject
	from PythonQt import QtGui
	from gui import mainWindow
	import os
	project_dir = QtGui.QFileDialog.getExistingDirectory(mainWindow,u"Укажите каталог нового проекта",project.baseDir)
	if not os.path.exists(project_dir):
		return
	if not closeProject():
		return
	maps_dir=os.path.join(project_dir,'maps')
	if not os.path.exists(maps_dir):
		os.mkdir(maps_dir)
	project.baseDir=project_dir
	project.settings.beginGroup("Map")
	project.settings.setValue("1/name","OSM Mapnik")
	project.settings.setValue("1/dbFile","maps/Mapnik.sqlitedb")
	project.settings.setValue("1/tileServer","http://tile.openstreetmap.org/%1/%2/%3.png")
	project.settings.setValue("size",1)
	project.settings.endGroup()
	editProject()
	project.projectLoaded(u'Создание проекта')

def editProject():
	plugins.EditorPlugin.editProject(project)

def editProjectSettins():
	plugins.EditorPlugin.editIniFile(project.settings.fileName())

def editOsmProperies():
	from gui import osmView
	plugins.EditorPlugin.editOsmProperies(project.settings,osmView)

def editPresets():
	from gui import osmView
	plugins.EditorPlugin.editPresets(project.settings,osmView)

newObjects={}
def newObjectConnected(obj_id,isConnected):
	obj=project.object(obj_id)
	if obj and not obj.property("temporary"):
		return

	if isConnected and not obj:
		obj=project.createObject()
		if not obj:
			return
		obj.id=obj_id
		obj.setProperty("temporary",True)
		newObjects[obj_id]=obj
		project.addObject(obj)
		obj.refresh(project.connection)
		kernel.itemModel.addObjects(u'Новые контроллеры',(obj,))
